@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -34,14 +34,15 @@
 #  endif
 # endif
 #endif
-#include <stdint.h>		/* POSIX/Gnulib */
+#include <stdint.h>		/* Gnulib/POSIX */
 #include <stdio.h>		/* C89 */
-#include <stdbool.h>		/* POSIX/Gnulib */
+#include <stdbool.h>		/* Gnulib/POSIX */
 #include <stdlib.h>		/* C89 */
-#include "gettext.h"
+#include "gettext.h"		/* Gnulib */
+#include "xalloc.h"		/* Gnulib */
+#include "minmax.h"		/* Gnulib */
 #define _(s) gettext(s)
 #define N_(s) gettext_noop(s)
-#include "common/memory.h"
 #include "common/io-utils.h"
 #include "common/error.h"
 #include "icotool.h"
@@ -90,10 +91,10 @@ create_icon(int filec, char **filev, CreateNameGen outfile_gen, bool icon_mode,
 	uint32_t dib_start;
 	png_byte ct;
 
-	img = xmalloc_clear(filec * sizeof(*img));
+	img = xzalloc(filec * sizeof(*img));
 
 	for (c = 0; c < filec; c++) {
-		char header[8];
+		uint8_t header[8];
 		uint32_t row_bytes;
 		uint8_t transparency[256];
 		uint16_t transparency_count;
@@ -198,6 +199,8 @@ create_icon(int filec, char **filev, CreateNameGen outfile_gen, bool icon_mode,
 			for (d = 1; palette_count(img[c].palette) > 1 << d; d <<= 1);
 			if (d == 2)	/* four colors (two bits) are not supported */
 				d = 4;
+		        /*if (d < min_bit_depth)
+				d = min_bit_depth;*/
 			img[c].bit_count = d;
 			img[c].palette_count = 1 << d;
 		}
@@ -306,12 +309,12 @@ create_icon(int filec, char **filev, CreateNameGen outfile_gen, bool icon_mode,
 			 * not necessary according to the original specs, but many
 			 * programs that read icons assume it. Especially gdk-pixbuf.
 			 */
-		    	memclear(&color, sizeof(Win32RGBQuad));
+		    	memset(&color, 0, sizeof(Win32RGBQuad));
 			for (d = palette_count(img[c].palette); d < 1 << img[c].bit_count; d++)
 				fwrite(&color, sizeof(Win32RGBQuad), 1, out);
 		}
 
-		img[c].image_data = xmalloc_clear(img[c].image_size);
+		img[c].image_data = xzalloc(img[c].image_size);
 
 		for (d = 0; d < img[c].height; d++) {
 			png_bytep row = img[c].row_datas[img[c].height - d - 1];
@@ -371,7 +374,7 @@ create_icon(int filec, char **filev, CreateNameGen outfile_gen, bool icon_mode,
 		png_read_end(img[c].png_ptr, img[c].info_ptr);
 		png_destroy_read_struct(&img[c].png_ptr, &img[c].info_ptr, NULL);
 		fclose(img[c].in);
-		memclear(&img[c], sizeof(*img));
+		memset(&img[c], 0, sizeof(*img));
 	}
 
 	free(outname);
