@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -37,14 +37,15 @@
 #  endif
 # endif
 #endif
-#include "gettext.h"
+#include "gettext.h"		/* Gnulib */
+#include "minmax.h"		/* Gnulib */
 #define _(s) gettext(s)
 #define N_(s) gettext_noop(s)
+#include "xalloc.h"		/* Gnulib */
 #include "common/strbuf.h"
 #include "common/string-utils.h"
 #include "common/io-utils.h"
 #include "common/error.h"
-#include "common/memory.h"
 #include "icotool.h"
 #include "win32-endian.h"
 
