@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef WIN32_H
@@ -52,7 +52,7 @@ typedef struct {
     uint16_t reserved;
     uint16_t type;
     uint16_t count;
-    Win32CursorIconDirEntry entries[0] PACKED;
+    Win32CursorIconDirEntry entries[0] /*PACKED*/;
 } Win32CursorIconDir;
 
 typedef struct {
