@@ -13,17 +13,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
-#include <inttypes.h>			/* ? */
-#include "gettext.h"			/* Gnulib */
+#include <inttypes.h>		/* ? */
+#include "gettext.h"		/* Gnulib */
 #define _(s) gettext(s)
 #define N_(s) gettext_noop(s)
-#include "common/intparse.h"
-#include "common/memory.h"
+#include "common/intutil.h"
+#include "xalloc.h"		/* Gnulib */
+#include "minmax.h"		/* Gnulib */
 #include "common/error.h"
 #include "wrestool.h"
 #include "win32.h"
@@ -456,7 +457,7 @@ read_library (WinLibrary *fi)
 			return false;
 		}
 
-		fi->first_resource = fi->memory + dir->virtual_address;
+		fi->first_resource = ((uint8_t *) fi->memory) + dir->virtual_address;
 		fi->is_PE_binary = true;
 		return true;
 	}
